[![pypi](https://img.shields.io/pypi/v/weneda)](https://pypi.org/project/weneda)
[![python](https://img.shields.io/badge/python-3.11+-blue)](https://www.python.org/downloads)
[![python](https://img.shields.io/badge/support-yellow)](https://www.buymeacoffee.com/eeemoon)

# weneda
Python module for editing and styling text.
